@@ -1,9 +1,11 @@
 mod elements;
+mod link;
 mod literal;
 mod value;
 
 pub use self::{
     elements::*,
+    link::SmartLink,
     literal::Literal,
     value::{Value, ValueType},
 };
@@ -51,7 +53,7 @@ pub enum ASTKind {
     MathNode(Box<MathNode>),
     /// block: ``` a ```
     /// span: `` `code`  ``
-    LinkNode(Box<SmartLink>),
+    LinkNode(SmartLink),
     /// span
     TextSpan(Box<TextNode>),
     /// span
